<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reset Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => __('Passwords must be at least six characters and match the confirmation.'),
    'reset' => __('Your password has been reset!'),
    'sent' => __('We have e-mailed your password reset link!'),
    'token' => __('This password reset token is invalid.'),
    'user' => __("We can't find a user with that e-mail address."),

];
