<!DOCTYPE HTML>
<html lang="en-US">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="refresh" content="0; url={{$url}}">
    <script type="text/javascript">
        window.location.href = "{{$url}}"
    </script>
    <title>Page Redirection</title>
</head>
<body>
If you are not redirected automatically, follow this <a href='{{$url}}'>link to documentation</a>.
</body>
</html>