body, html {
    -webkit-font-smoothing: antialiased;
    -webkit-tap-highlight-color: transparent;
    -webkit-touch-callout: none;
    -webkit-text-size-adjust: 100%;
    -ms-text-size-adjust: 100%;
    -moz-osx-font-smoothing: grayscale;
    width: 100%;
    height: 100%;
    position: relative;
    color: rgba(0, 0, 0, 0.87);
    box-sizing: border-box;
}

html {
    font-size: 62.5%;
    touch-action: manipulation;
}

body {
    font-family: Roboto, "Helvetica Neue", sans-serif;
    line-height: 1.42857143;
    font-size: 1.4rem;
    background-color: #FAFAFA;
    margin: 0;
    transition: opacity ease-in-out;
}

::-moz-selection {
    background: #b3d4fc;
    text-shadow: none;
}

::selection {
    background: #b3d4fc;
    text-shadow: none;
}

a {
    display: inline-block;
    text-decoration: none;
    color: #1565c0;
    font-weight: 400;
}

code.style {
    color: #bd4147;
    background-color: #f7f7f9;
}

pre.style {
    font-family: inherit;
    font-size: 1.4rem;
}

form {
    margin: 0
}

img {
    display: block;
}

.container {
    max-width: 1190px;
    margin: 0 auto;
    width: 100%;
}

.hidden {
    display: none !important;
    visibility: hidden;
}

.relative {
    position: relative;
}

.inline {
    display: inline-block;
}

.capitalize {
    text-transform: capitalize;
}